@@ -1,14 +1,15 @@
 import logging
-from ploomber.dag.DAG import DAG
-from ploomber.dag.InMemoryDAG import InMemoryDAG
-from ploomber.dag.DAGConfigurator import DAGConfigurator
-from ploomber.dag.OnlineDAG import OnlineDAG, OnlineModel
+from ploomber.dag.dag import DAG
+from ploomber.dag.inmemorydag import InMemoryDAG
+from ploomber.dag.dagconfigurator import DAGConfigurator
+from ploomber.dag.onlinedag import OnlineDAG, OnlineModel
 from ploomber.env.env import Env
 from ploomber.env.decorators import load_env, with_env
-from ploomber.placeholders.SourceLoader import SourceLoader
+from ploomber.placeholders.sourceloader import SourceLoader
 from ploomber.jupyter.manager import _load_jupyter_server_extension
+from ploomber.util.loader import lazily_load_entry_point
 
-__version__ = '0.11.1'
+__version__ = '0.12'
 
 # Set default logging handler to avoid "No handler found" warnings.
 
@@ -24,6 +25,7 @@ __all__ = [
     'InMemoryDAG',
     'OnlineDAG',
     'OnlineModel',
+    'lazily_load_entry_point',
 ]
 
 
