@@ -94,17 +94,16 @@ from itertools import chain
 import pprint
 import warnings
 
-from ploomber.dag.DAG import DAG
-from ploomber.placeholders.SourceLoader import SourceLoader
+from ploomber.dag.dag import DAG
+from ploomber.placeholders.sourceloader import SourceLoader
 from ploomber.util.util import call_with_dictionary, add_to_sys_path
 from ploomber.util import dotted_path
-from ploomber.util.default import entry_point, entry_point_relative
 from ploomber.spec.taskspec import TaskSpec, suffix2taskclass
 from ploomber.util import validate
 from ploomber.util import default
-from ploomber.dag.DAGConfiguration import DAGConfiguration
+from ploomber.dag.dagconfiguration import DAGConfiguration
 from ploomber.exceptions import DAGSpecInitializationError
-from ploomber.env.EnvDict import EnvDict
+from ploomber.env.envdict import EnvDict
 from ploomber.env.expand import (expand_raw_dictionary_and_extract_tags,
                                  expand_raw_dictionaries_and_extract_tags)
 from ploomber.tasks import NotebookRunner
@@ -133,7 +132,12 @@ class DAGSpec(MutableMapping):
     Parameters
     ----------
     data : str, pathlib.Path or dict
-        Path to a YAML spec or dict spec
+        Path to a YAML spec or dict spec. If loading from a file, sources
+        and products are resolved to the file's parent. If the file is in a
+        packaged structure (i.e., src/package/pipeline.yaml), the existence
+        of a setup.py in the same folder as src/ is validated. If loaded from
+        a dict, sources and products aren't resolved, unless a parent_path
+        is not None.
 
     env : dict, pathlib.path or str, optional
         If path it must be a YAML file. Environment to load. Any string with
@@ -152,13 +156,18 @@ class DAGSpec(MutableMapping):
         with the dotted path, which means some verifications such as import
         statements in that function's module are delayed until the pipeline
         is executed. This also applies to placeholders loaded using a
-        SourceLoader, if a placeholder exists, it will return the path
-        to it, instead of an initialized Placeholder object, if it doesn't,
-        it will return None instead of raising an error.
+        SourceLoader, if a template exists, it will return the path
+        to it, instead of initializing it, if it doesn't, it will return None
+        instead of raising an error. This setting is useful when we require to
+        load YAML spec and instantiate the DAG object to extract information
+        from it (e.g., which are the declared tasks) but the process running
+        it may not have all the required dependencies to do so (e.g., an
+        imported library in a PythonCallable task).
 
     reload : bool, optional
-        Reloads modules before getting dotted paths. Has no effect if
-        lazy_import=True
+        Reloads modules before importing dotted paths to detect code changes
+        if the module has already been imported. Has no effect if
+        lazy_import=True.
 
     Attributes
     ----------
@@ -183,18 +192,32 @@ class DAGSpec(MutableMapping):
                  lazy_import=False,
                  reload=False,
                  parent_path=None):
+        self._init(data=data,
+                   env=env,
+                   lazy_import=lazy_import,
+                   reload=reload,
+                   parent_path=parent_path,
+                   look_up_project_root_recursively=True)
+
+    def _init(self, data, env, lazy_import, reload, parent_path,
+              look_up_project_root_recursively):
         # initialized with a path to a yaml file...
         if isinstance(data, (str, Path)):
+            # TODO: test this
             if parent_path is not None:
                 raise ValueError('parent_path must be None when '
                                  f'initializing {type(self).__name__} with '
                                  'a path to a YAML spec')
-            self._path = data
             # resolve the parent path to make sources and products unambiguous
             # even if the current working directory changes
-            path_to_entry_point = Path(data).resolve()
+            self._path = Path(data).resolve()
+            self._parent_path = str(self._path.parent)
 
-            self._parent_path = str(path_to_entry_point.parent)
+            if not Path(data).is_file():
+                raise FileNotFoundError(
+                    'Error initializing DAGSpec with argument '
+                    f'{data!r}: Expected it to be a path to a YAML file, but '
+                    'such file does not exist')
 
             content = Path(data).read_text()
 
@@ -230,9 +253,6 @@ class DAGSpec(MutableMapping):
             self._parent_path = (None if not parent_path else str(
                 Path(parent_path).resolve()))
 
-        # try to look env.yaml in default locations
-        env_default_path = default.path_to_env(self._parent_path)
-
         self.data = data
 
         if isinstance(self.data, list):
@@ -244,15 +264,11 @@ class DAGSpec(MutableMapping):
         logger.debug('DAGSpec enviroment:\n%s', pp.pformat(env))
 
         env = env or dict()
+        path_to_defaults = default.path_to_env_from_spec(
+            path_to_spec=self._path)
 
-        # NOTE: when loading from a path, EnvDict recursively looks
-        # at parent folders, this is useful when loading envs
-        # in nested directories where scripts/functions need the env
-        # but here, since we just need this for the spec, we might
-        # want to turn it off. should we add a parameter to EnvDict
-        # to control this?
-        if env_default_path:
-            defaults = yaml.safe_load(Path(env_default_path).read_text())
+        if path_to_defaults:
+            defaults = yaml.safe_load(Path(path_to_defaults).read_text())
             self.env = EnvDict(env,
                                path_to_here=self._parent_path,
                                defaults=defaults)
@@ -317,10 +333,17 @@ class DAGSpec(MutableMapping):
                 normalize_task(task) for task in self.data['tasks']
             ]
 
-            # "products" are relative to the project root. if no project
-            # root, then use the parent path
-            project_root = (default.find_root_recursively()
-                            or self._parent_path)
+            # NOTE: for simple projects, project root is the parent folder
+            # of pipeline.yaml, for package projects is the parent folder
+            # of setup.py
+            if look_up_project_root_recursively:
+                project_root = (
+                    None if not self._parent_path else
+                    default.find_root_recursively(
+                        starting_dir=self._parent_path,
+                        filename=None if not self._path else self._path.name))
+            else:
+                project_root = self._parent_path
 
             # make sure the folder where the pipeline is located is in sys.path
             # otherwise dynamic imports needed by TaskSpec will fail
@@ -436,54 +459,6 @@ class DAGSpec(MutableMapping):
     def path(self):
         return self._path
 
-    @classmethod
-    def _auto_load(cls,
-                   to_dag=True,
-                   starting_dir=None,
-                   env=None,
-                   lazy_import=False,
-                   reload=False,
-                   name=None):
-        """
-        NOTE: this is a private API. Use DAGSpec.find() instead
-
-        Looks for a pipeline.yaml, generates a DAGSpec and returns a DAG.
-        Currently, this is only used by the PloomberContentsManager, this is
-        not intended to be a public API since initializing specs from paths
-        where we have to recursively look for a pipeline.yaml has some
-        considerations regarding relative paths that make this confusing,
-        inside the contents manager, all those things are all handled for that
-        use case.
-
-        The pipeline.yaml parent folder is temporarily added to sys.path when
-        calling DAGSpec.to_dag() to make sure imports work as expected
-
-        Returns DAG and the directory where the pipeline.yaml file is located.
-        """
-        root_path = starting_dir or os.getcwd()
-        rel_path = entry_point(root_path=root_path, name=name)
-
-        if rel_path is None:
-            if to_dag:
-                return None, None, None
-            else:
-                return None, None
-
-        path = Path(root_path, rel_path)
-
-        try:
-            spec = cls(path, env=env, lazy_import=lazy_import, reload=reload)
-
-            if to_dag:
-                return spec, spec.to_dag(), Path(path).parent
-            else:
-                return spec, Path(path).parent
-
-        except Exception as e:
-            exc = DAGSpecInitializationError('Error initializing DAG from '
-                                             f'{path!s}')
-            raise exc from e
-
     @classmethod
     def _find_relative(cls, name=None):
         """
@@ -497,7 +472,7 @@ class DAGSpec(MutableMapping):
         is used for loading the DAG and submitting tasks and as an argument
         in "ploomber task --entry-point {relative-path}" when executing tasks
         """
-        path = entry_point_relative(name=name)
+        path = default.entry_point_relative(name=name)
         return cls(path)
 
     @classmethod
@@ -518,15 +493,21 @@ class DAGSpec(MutableMapping):
 
         name : str, default=None
             Filename to search for. If None, it looks for a pipeline.yaml file,
-            otherwise it looks for a pipeline.{name}.yaml file.
+            otherwise it looks for a file with such name.
         """
-        spec, _ = DAGSpec._auto_load(to_dag=False,
-                                     starting_dir=starting_dir,
-                                     env=env,
-                                     lazy_import=lazy_import,
-                                     reload=reload,
-                                     name=name)
-        return spec
+        starting_dir = starting_dir or os.getcwd()
+        path_to_entry_point = default.entry_point_with_name(
+            root_path=starting_dir, name=name)
+
+        try:
+            return cls(path_to_entry_point,
+                       env=env,
+                       lazy_import=lazy_import,
+                       reload=reload)
+        except Exception as e:
+            exc = DAGSpecInitializationError('Error initializing DAG from '
+                                             f'{path_to_entry_point!s}')
+            raise exc from e
 
     @classmethod
     def from_directory(cls, path_to_dir):
@@ -594,6 +575,32 @@ class DAGSpec(MutableMapping):
         return cls({'tasks': tasks, 'meta': meta})
 
 
+class DAGSpecPartial(DAGSpec):
+    """
+    A DAGSpec subclass that initializes from a list of tasks (used in the
+    onlinedag.py) module
+    """
+    def __init__(self, path_to_partial, env=None):
+        with open(path_to_partial) as f:
+            tasks = yaml.safe_load(f)
+
+        if not isinstance(tasks, list):
+            raise ValueError(
+                f'Expected partial {path_to_partial!r} to be a '
+                f'list of tasks, but got a {type(tasks).__name__} instead')
+
+        # cannot extract upstream because this is an incomplete DAG
+        meta = {'extract_product': False, 'extract_upstream': False}
+        data = {'tasks': tasks, 'meta': meta}
+
+        self._init(data=data,
+                   env=env,
+                   lazy_import=False,
+                   reload=False,
+                   parent_path=Path(path_to_partial).parent,
+                   look_up_project_root_recursively=False)
+
+
 class Meta:
     """Schema for meta section in pipeline.yaml
     """
@@ -636,7 +643,7 @@ class Meta:
             meta['product_relative_to_source'] = False
 
         if 'jupyter_hot_reload' not in meta:
-            meta['jupyter_hot_reload'] = False
+            meta['jupyter_hot_reload'] = True
 
         if 'jupyter_functions_as_notebooks' not in meta:
             meta['jupyter_functions_as_notebooks'] = False
