@@ -17,7 +17,7 @@ class SQLScript(Task):
     source: str or pathlib.Path
         SQL script source, if str, the content is interpreted as the actual
         script, if pathlib.Path, the content of the file is loaded
-    product: ploomber.products.Product
+    product: ploomber.products.product
         Product generated upon successful execution
     dag: ploomber.DAG
         A DAG to add this task to
@@ -91,7 +91,7 @@ class SQLDump(io.FileLoaderMixin, Task):
     source: str or pathlib.Path
         SQL script source, if str, the content is interpreted as the actual
         script, if pathlib.Path, the content of the file is loaded
-    product: ploomber.products.Product
+    product: ploomber.products.product
         Product generated upon successful execution
     dag: ploomber.DAG
         A DAG to add this task to
@@ -214,7 +214,7 @@ class SQLTransfer(Task):
     source: str or pathlib.Path
         SQL script source, if str, the content is interpreted as the actual
         script, if pathlib.Path, the content of the file is loaded
-    product: ploomber.products.Product
+    product: ploomber.products.product
         Product generated upon successful execution. For SQLTransfer, usually
         product.client != task.client. task.client represents the data source
         while product.client represents the data destination
@@ -306,7 +306,7 @@ class SQLUpload(Task):
     source : str or pathlib.Path
         Path to parquet or a csv file to upload
 
-    product : ploomber.products.Product
+    product : ploomber.products.product
         Product generated upon successful execution. The client for the product
         must be in the target database, where as task.client should be a client
         in the source database.
@@ -446,8 +446,6 @@ class PostgresCopyFrom(Task):
                  name=None,
                  client=None,
                  params=None,
-                 sep='\t',
-                 null='\\N',
                  columns=None):
         params = params or {}
         kwargs = dict(hot_reload=dag._params.hot_reload)
@@ -460,8 +458,6 @@ class PostgresCopyFrom(Task):
             raise ValueError('{} must be initialized with a connection'.format(
                 type(self).__name__))
 
-        self.sep = sep
-        self.null = null
         self.columns = columns
 
     @staticmethod
@@ -483,9 +479,6 @@ class PostgresCopyFrom(Task):
                           index=False)
         self._logger.info('Done creating table.')
 
-        # if product.kind != 'table':
-        #     raise ValueError('COPY is only supportted in tables')
-
         # create file-like object
         f = StringIO()
         df.to_csv(f, sep='\t', na_rep='\\N', header=False, index=False)
@@ -495,7 +488,7 @@ class PostgresCopyFrom(Task):
         cur = self.client.connection.cursor()
 
         self._logger.info('Copying data...')
-        cur.copy_from(f, table=str(product), sep='\t', null='\\N')
+        cur.copy_expert(f'COPY {product} FROM STDIN', f)
 
         f.close()
         cur.close()
